@@ -8,6 +8,10 @@
         <source>Theme Customizer</source>
         <translation>Customiser le thème</translation>
     </message>
+    <message>
+        <source>Tune transitions</source>
+        <translation></translation>
+    </message>    
     <message>
         <source>Theme</source>
         <translation>Thème</translation>
